==> nextcloud-26.0.11p1.tgz: nextcloud/apps/oauth2/l10n/hu.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Az Ön kliensalkalmazása számára nem engedélyezett a kapcsolódás. Értesítse a kliense rendszergazdáját.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Az átirányítási URL-jének teljes URL-nek kell lennie, például: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Lehetővé teszi az OAuth2 kompatibilis hitelesítést más webalkalmazásokból.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Az OAuth2 alkalmazás lehetővé teszi a rendszergazdák számára, hogy beállíthassák a beépített azonosítási munkafolyamat számára az OAuth2 kompatibilis hitelesítést más webalkalmazásokból.",
    "OAuth 2.0 clients" : "OAuth 2.0 kliensek",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "Az OAuth 2.0 engedélyezi, hogy külső szolgáltatások hozzáférést kérjenek a következőhöz: {instanceName}.",
    "Name" : "Név",
    "Redirection URI" : "Átirányítési URI",
    "Client Identifier" : "Ügyfélazonosító",
    "Secret key" : "Titkos kulcs",
    "Add client" : "Kliens hozzáadása",
    "Add" : "Hozzáadás",
    "Delete" : "Törlés",
    "Show client secret" : "Kliens titkának megjelenítése",
    "Secret" : "Titok"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/oauth2/l10n/hu.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Az Ön kliensalkalmazása számára nem engedélyezett a kapcsolódás. Értesítse a kliense rendszergazdáját.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Az átirányítási URL-jének teljes URL-nek kell lennie, például: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Lehetővé teszi az OAuth2 kompatibilis hitelesítést más webalkalmazásokból.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Az OAuth2 alkalmazás lehetővé teszi a rendszergazdák számára, hogy beállíthassák a beépített azonosítási munkafolyamat számára az OAuth2 kompatibilis hitelesítést más webalkalmazásokból.",
    "OAuth 2.0 clients" : "OAuth 2.0 kliensek",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "Az OAuth 2.0 engedélyezi, hogy külső szolgáltatások hozzáférést kérjenek a következőhöz: {instanceName}.",
    "Name" : "Név",
    "Redirection URI" : "Átirányítási URI",
    "Client Identifier" : "Ügyfélazonosító",
    "Secret key" : "Titkos kulcs",
    "Delete client" : "Kliens törlése",
    "Make sure you store the secret key, it cannot be recovered." : "Győződjön meg róla tárolja a titkos kulcsot, mert nem nyerhető vissza.",
    "Add client" : "Kliens hozzáadása",
    "Add" : "Hozzáadás",
    "Show client secret" : "Klienstitok megjelenítése",
    "Hide client secret" : "Klienstitok elrejtése",
    "Delete" : "Törlés"
},
"nplurals=2; plural=(n != 1);");
